package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.huiju.estateagents.service.ITaMpTemplateService;
import com.huiju.estateagents.entity.TaMpTemplate;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    *  前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-23
 */

@Api(tags = "")
@RestController
@RequestMapping("/api")
public class TaMpTemplateController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaMpTemplateController.class);

    @Autowired
    public ITaMpTemplateService iTaMpTemplateService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taMpTemplate",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMpTemplateList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         HttpServletRequest request) throws Exception{

		    IPage<TaMpTemplate> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaMpTemplate> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id", getOrgId(request));
            queryWrapper.eq("status", CommConstant.STATUS_NORMAL);
            queryWrapper.orderByDesc("create_date");

            IPage<TaMpTemplate> result = iTaMpTemplateService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taMpTemplate 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taMpTemplate",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taMpTemplateAdd(@ApiParam("保存内容") @RequestBody TaMpTemplate taMpTemplate,
                                        HttpServletRequest request) throws Exception{

        taMpTemplate.setOrgId(getOrgId(request));
        if (iTaMpTemplateService.save(taMpTemplate)){
            return ResponseBean.success(taMpTemplate);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taMpTemplate/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taMpTemplateDelete(@ApiParam("对象ID") @PathVariable Integer id,
                                           HttpServletRequest request) throws Exception{
        TaMpTemplate taMpTemplate = iTaMpTemplateService.getById(id);
        if (null == taMpTemplate || taMpTemplate.getStatus().equals(CommConstant.STATUS_DELETE)) {
            return ResponseBean.success("success");
        }

        if (!getOrgId(request).equals(taMpTemplate.getOrgId())) {
            return ResponseBean.error("您无权进行当前操作", ResponseBean.ERROR_UNAVAILABLE);
        }

        taMpTemplate.setStatus(CommConstant.STATUS_DELETE);
        return taMpTemplateUpdate(id, taMpTemplate, request);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taMpTemplate 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taMpTemplate/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taMpTemplateUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                           @ApiParam("更新内容") @RequestBody TaMpTemplate taMpTemplate,
                                           HttpServletRequest request) throws Exception{

        if (!getOrgId(request).equals(taMpTemplate.getOrgId())) {
            return ResponseBean.error("您无权进行当前操作", ResponseBean.ERROR_UNAVAILABLE);
        }

        taMpTemplate.setSerialNo(id);
        if (iTaMpTemplateService.updateById(taMpTemplate)){
            return ResponseBean.success(iTaMpTemplateService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/taMpTemplate/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taMpTemplateGet(@ApiParam("对象ID") @PathVariable Integer id,
                                        HttpServletRequest request) throws Exception{
        TaMpTemplate taMpTemplate = iTaMpTemplateService.getById(id);
        if (null == taMpTemplate || taMpTemplate.getStatus().equals(CommConstant.STATUS_DELETE)) {
            return ResponseBean.error("数据不存在", ResponseBean.ERROR_UNAVAILABLE);
        }

        if (!getOrgId(request).equals(taMpTemplate.getOrgId())) {
            return ResponseBean.error("您无权进行当前操作", ResponseBean.ERROR_UNAVAILABLE);
        }

        return ResponseBean.success(taMpTemplate);
    }
}
